==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/outputs/DefaultRolloutSpecificationResponseProviderRegistration.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property name The name of the resource
 * @property properties
 * @property systemData Metadata pertaining to creation and last modification of the resource.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class DefaultRolloutSpecificationResponseProviderRegistration(
    public val id: String,
    public val name: String,
    public val properties: ProviderRegistrationResponseProperties? = null,
    public val systemData: SystemDataResponse,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.providerhub.outputs.DefaultRolloutSpecificationResponseProviderRegistration):
            DefaultRolloutSpecificationResponseProviderRegistration =
            DefaultRolloutSpecificationResponseProviderRegistration(
                id = javaType.id(),
                name = javaType.name(),
                properties = javaType.properties().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.providerhub.kotlin.outputs.ProviderRegistrationResponseProperties.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                systemData = javaType.systemData().let({ args0 ->
                    com.pulumi.azurenative.providerhub.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
                }),
                type = javaType.type(),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/outputs/DefaultRolloutSpecificationResponseProviderRegistration.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property name The name of the resource
 * @property properties
 * @property systemData Metadata pertaining to creation and last modification of the resource.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class DefaultRolloutSpecificationResponseProviderRegistration(
    public val id: String,
    public val name: String,
    public val properties: ProviderRegistrationResponseProperties? = null,
    public val systemData: SystemDataResponse,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.providerhub.outputs.DefaultRolloutSpecificationResponseProviderRegistration): DefaultRolloutSpecificationResponseProviderRegistration =
            DefaultRolloutSpecificationResponseProviderRegistration(
                id = javaType.id(),
                name = javaType.name(),
                properties = javaType.properties().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.providerhub.kotlin.outputs.ProviderRegistrationResponseProperties.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                systemData = javaType.systemData().let({ args0 ->
                    com.pulumi.azurenative.providerhub.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
                }),
                type = javaType.type(),
            )
    }
}
